"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Mqtt = void 0;
const mqtt = require('mqtt');
class Mqtt {
    constructor(config, log) {
        this.log = log;
        this.config = config;
        if (!config || !config.broker) {
            return;
        }
        const options = {};
        if (config.username) {
            options.username = config.username;
            if (config.password) {
                options.password = config.password;
            }
        }
        this.client = mqtt.connect(config.broker, options);
        this.client.on('connect', () => {
            this.log.debug('Connected to MQTT broker');
        });
        this.client.on('error', (error) => {
            this.log.error('MQTT error: ' + error.message);
        });
    }
    sendMessageOnTopic(message, topic) {
        if (this.client && this.client.connected) {
            this.client.publish(this.config.topicPrefix + '/' + topic, message);
        }
    }
    onConnection() {
        return new Promise((resolve, reject) => {
            let interval = setInterval(() => {
                if (this.client.connected) {
                    clearInterval(interval);
                    resolve();
                }
            }, 10);
        });
    }
    subscribeToTopic(topic, callback) {
        this.onConnection().then(() => {
            this.log.debug('Subscribing to: ' + this.config.topicPrefix + '/' + topic);
            this.client.subscribe(this.config.topicPrefix + '/' + topic, (err, granted) => {
                console.log(granted);
                if (!err) {
                    if (granted && granted.length === 1) {
                        this.client.on('message', (messageTopic, messagePayload, packet) => {
                            if (messageTopic === this.config.topicPrefix + '/' + topic) {
                                callback(JSON.parse(messagePayload.toString()));
                            }
                        });
                    }
                }
            });
        });
    }
}
exports.Mqtt = Mqtt;
//# sourceMappingURL=mqtt.js.map